        function getT(rr,cc){
       if(rr==7 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260624 a 00</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==7 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260624 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>44</strong> miembros: 23 <strong>control</strong><br>0,4,6,9,13,14,15,16,17,18,20,21,26,27,31,32,33,36,40,42,44,45,48';}
       if(rr==7 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260624 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>34</strong> miembros: 19 <br>1,2,3,7,8,10,11,22,24,25,29,30,34,35,37,38,41,43,50';}
       if(rr==7 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260624 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>3</strong> representante: <strong>28</strong> miembros: 9 <br>5,12,19,23,28,39,46,47,49';}
       if(rr==34 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260624 a 00</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==34 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260624 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>44</strong> miembros: 23 <strong>control</strong><br>0,4,6,9,13,14,15,16,17,18,20,21,26,27,31,32,33,36,40,42,44,45,48';}
       if(rr==34 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260624 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>34</strong> miembros: 19 <br>1,2,3,7,8,10,11,22,24,25,29,30,34,35,37,38,41,43,50';}
       if(rr==34 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260624 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>3</strong> representante: <strong>28</strong> miembros: 9 <br>5,12,19,23,28,39,46,47,49';}
       if(rr==35 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260624 a 00</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==35 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260624 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>44</strong> miembros: 23 <strong>control</strong><br>0,4,6,9,13,14,15,16,17,18,20,21,26,27,31,32,33,36,40,42,44,45,48';}
       if(rr==35 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260624 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>34</strong> miembros: 19 <br>1,2,3,7,8,10,11,22,24,25,29,30,34,35,37,38,41,43,50';}
       if(rr==35 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260624 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>3</strong> representante: <strong>28</strong> miembros: 9 <br>5,12,19,23,28,39,46,47,49';}
       if(rr==36 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260624 a 00</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==36 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260624 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>44</strong> miembros: 23 <strong>control</strong><br>0,4,6,9,13,14,15,16,17,18,20,21,26,27,31,32,33,36,40,42,44,45,48';}
       if(rr==36 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260624 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>34</strong> miembros: 19 <br>1,2,3,7,8,10,11,22,24,25,29,30,34,35,37,38,41,43,50';}
       if(rr==36 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260624 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>3</strong> representante: <strong>28</strong> miembros: 9 <br>5,12,19,23,28,39,46,47,49';}
       if(rr==37 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260624 a 00</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==37 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260624 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>44</strong> miembros: 23 <strong>control</strong><br>0,4,6,9,13,14,15,16,17,18,20,21,26,27,31,32,33,36,40,42,44,45,48';}
       if(rr==37 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260624 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>34</strong> miembros: 19 <br>1,2,3,7,8,10,11,22,24,25,29,30,34,35,37,38,41,43,50';}
       if(rr==37 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260624 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>3</strong> representante: <strong>28</strong> miembros: 9 <br>5,12,19,23,28,39,46,47,49';}
       if(rr==38 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260624 a 00</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==38 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260624 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>44</strong> miembros: 23 <strong>control</strong><br>0,4,6,9,13,14,15,16,17,18,20,21,26,27,31,32,33,36,40,42,44,45,48';}
       if(rr==38 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260624 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>34</strong> miembros: 19 <br>1,2,3,7,8,10,11,22,24,25,29,30,34,35,37,38,41,43,50';}
       if(rr==38 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260624 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>3</strong> representante: <strong>28</strong> miembros: 9 <br>5,12,19,23,28,39,46,47,49';}
       if(rr==39 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260624 a 00</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==39 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260624 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>44</strong> miembros: 23 <strong>control</strong><br>0,4,6,9,13,14,15,16,17,18,20,21,26,27,31,32,33,36,40,42,44,45,48';}
       if(rr==39 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260624 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>34</strong> miembros: 19 <br>1,2,3,7,8,10,11,22,24,25,29,30,34,35,37,38,41,43,50';}
       if(rr==39 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260624 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>3</strong> representante: <strong>28</strong> miembros: 9 <br>5,12,19,23,28,39,46,47,49';}
}
